<div class="constrain_field">
	<input size="{$?,{$MOBILE},34,40}" tabindex="{TABINDEX*}" class="input_email{REQUIRED*}" maxlength="255" type="email" id="{NAME*}" name="{NAME*}" value="{DEFAULT*}" />
</div>

