.openid_wrap {
	overflow: scroll;
	width: 100%;
}

#openid {
	background: url({$IMG;,openid/indicator}) center center no-repeat;
	margin: 0 auto;
	width: 440px;
	/*height: 162px;*/
	font: 12px 'Arial';
}

#openid_inputarea {
	clear: both;
	display: none;
	background: url({$IMG;,openid/balloon}) no-repeat;
	width: 410px;
	height: 48px;
	color: white;
	position: absolute;visibility: hidden; /* Intentionally take the message out of the flow and hide it - it takes too much space */
	text-align: center;
	margin-top: 35px;
	padding-top: 17px;
}

#openid_inputarea #openid_username {
	margin: 0 4px 0 8px;
	width: 120px;
}

#openid_btns {
	overflow: hidden;
}

#openid_btns br {
	clear: left;
}

#openid_highlight {
	{$BETA_CSS_PROPERTY,border-radius: 10px;}
	padding: 2px;
	background-color: {$GET,area_background};
	float: left;
}

.openid_large_btn, .openid_small_btn {
	background: url({$IMG;,openid/openid-icons}) no-repeat;
	margin: 3px;
	float: left;
}

.openid_large_btn {
	width: 91px;
	height: 51px;
}

.openid_small_btn {
	width: 16px;
	height: 16px;
}

.Google { background-position: 0 0; }
.Yahoo { background-position: 0 -51px; }
.AOL { background-position: 0 -102px; }
.OpenID { background-position: 0 -153px; }
.MyOpenID { background-position: 0 -204px; }
.Flickr { background-position: 0 -220px; }
.Technorati { background-position: -17px -220px; }
.Wordpress { background-position: -17px -204px; }
.Blogger { background-position: -34px -204px; }
.Verisign { background-position: -51px -220px; }
.Vidoop { background-position: -34px -220px; }
.ClaimID { background-position: -68px -204px; }
.LiveJournal { background-position: -51px -204px; }
.MySpace { background-position: -68px -220px; }

a.openid_large_btn:focus {
	outline: none;
	-moz-outline-style: none;
}
